@@ -8,10 +8,18 @@ class Transaction:
 
     def __init__(self, to_wrap):
         self.to_wrap = to_wrap
+        self.clsObj = None
 
     def __call__(self, transaction, *args, **kwargs):
         @firestore.transactional
         def operate_transaction(transaction, *args, **kwargs):
-            return self.to_wrap(transaction, *args, **kwargs)
+            if self.clsObj:
+                return self.to_wrap(self.clsObj, transaction, *args, **kwargs)
+            else:
+                return self.to_wrap(transaction, *args, **kwargs)
 
-        return operate_transaction(transaction, *args, **kwargs)
\ No newline at end of file
+        return operate_transaction(transaction, *args, **kwargs)
+
+    def __get__(self, obj, objtype=None):
+        self.clsObj = obj
+        return self
