@@ -42,4 +42,7 @@ def get_nested(dict, *args):
             return value if len(args) == 1 else get_nested(value, *args[1:])
 
 def generateKeyFromId(model, id):
-    return model.collection_name + "/" + id
\ No newline at end of file
+    return model.collection_name + "/" + id
+
+def isKey(str):
+    return "/" in str
\ No newline at end of file
